<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DB\StorageProcedure\Param;
use Zeedhi\Framework\DTO\Response;

use Teknisa\CNC\Utilities\UtilCNC;
use Teknisa\Libs\Util\Environment;

use Teknisa\CNC\Services\Cnc00200AdquirentesService;

class Cnc00200Adquirentes extends \Teknisa\CNC\Controllers\TeknisaCrud {
    protected $dataSourceName = 'cnc00200_adquirentes';
	protected $parameterBagColumns;
	protected $service;
	protected $environment;
    protected $nrseq;

	public function __construct ($crudService, ParameterBag $parameterBagColumns, UtilCNC $util, Cnc00200AdquirentesService $service, Environment $environment) {
	    parent::__construct($crudService, $parameterBagColumns);
	    $this->util = $util;
        $this->service = $service;
        $this->environment = $environment;
	}
	
	public function save(DTO\Request $request, DTO\Response $response) {
		try {
			$dataSourceName = $this->dataSourceNameToSave ? $this->dataSourceNameToSave : $this->dataSourceName;
			$rows = $this->crudService->getRowsToSave($request, $dataSourceName);
			foreach ($rows as $row) {
			    if ($row['VRTAXAADM'] > 100)
                    throw new \Exception('Taxa superior ao limite de 100% (cem porcento).');
                if ($row['VRTAXAADM'] < 0)
                    throw new \Exception('A taxa não pode ser negativa.');
			    if ($row['VRTOLERANCIA'] > 0.1)
			        throw new \Exception('A tolerância máxima é de R$0,10 (dez centavos).');
			        
			    $row['VRTAXAADM'] = round($row['VRTAXAADM'], 5);
				$this->crudService->save($dataSourceName, [$row]);
				$response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
			}
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function setNrseq ($nrseq) {
        $this->nrseq = $nrseq;
    }
    
    public function getNrseq () {return $this->nrseq;}
    
    public function getAdquirentesSeries (Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            
            $filter["NRORG"] = $this->environment->getNrOrgTrab();
            
            $filter["NRESTABELEC"] = array_filter($filter, function($param) {
                return $param["columnName"] === "NRESTABELEC";
            });
            $filter["NRESTABELEC"] = array_shift($filter["NRESTABELEC"]);
            
            $data = $this->service->getAdquirentesSeries($filter);
            $response->addDataSet(new DataSet("cnc00200_adquirente_financeiroInsc", $data));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
    
    public function getInscValues (Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
            $row = []; 
            
            $row["NRORG"] = $this->environment->getNrOrgTrab();
            
            $row["NRESTABELEC"] = array_filter($filter, function($param) {
                return $param["columnName"] === "NRESTABELEC";
            });
            $row["NRESTABELEC"] = array_shift($row["NRESTABELEC"]);
            
            $data = $this->service->getInscValues($row);
            $response->addDataSet(new DataSet("cnc00200_adquirentes_getInscValues", $data));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }
}