<?php
namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request;
use Teknisa\CNC\Services;
use Teknisa\CNC\Utilities;

class Cnc01500AjustesAdquirentes extends \Zeedhi\Framework\Controller\Simple {
    
    protected $ajustAdqService;
    protected $salesMessage;
    
    public function __construct(Services\Cnc01500AjustesAdquirentes $ajustAdqService, Utilities\SalesMessageCNC $salesMessage) {
        $this->ajustAdqService  = $ajustAdqService;
        $this->salesMessage  = $salesMessage;
    }

    public function getAdjustmentAqcuires(Request\Filter $request, Response $response){
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            
            $params["NRESTABELEC"]  = $this->getParamValueFromConditions($conditions, "NRESTABELEC");
            $params["NRADQUIRENTE"] = $this->getParamValueFromConditions($conditions, "NRADQUIRENTE");
            $params["intervalo"]    = $this->getParamValueFromConditions($conditions, "intervalo");
            $params["DTVENDA"]      = $this->getParamValueFromConditions($conditions, "DTVENDA");
            $params["MESINI"]       = $this->getParamValueFromConditions($conditions, "MESINI");
            $params["MESFIN"]       = $this->getParamValueFromConditions($conditions, "MESFIN");
            $params["DTCREDITO"]    = $this->getParamValueFromConditions($conditions, "DTCREDITO");
            
            $params["NRESTABELEC"] = is_array($params["NRESTABELEC"]) ? 
                $this->buildParamValue($params["NRESTABELEC"]) : "Todas";
            $params["NRADQUIRENTE"] = is_array($params["NRADQUIRENTE"]) ? 
                $this->buildParamValue($params["NRADQUIRENTE"]) : "Todas";

            $resultado = $this->ajustAdqService->getAdjustmentAqcuires($params);
            $response->addDataSet(new DataSet('Cnc01500_ajustesAdquirentesRepo', $resultado));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function chartDetails (DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria()->getConditions();
        
            $params["NRORG"]        = $this->getParamValueFromConditions($filter, "NRORG");
            $params["NRESTABELEC"]  = $this->getParamValueFromConditions($filter, "NRESTABELEC");
            $params["NRADQUIRENTE"] = $this->getParamValueFromConditions($filter, "NRADQUIRENTE");
            $params["DTVENDA"]      = $this->getParamValueFromConditions($filter, "DTVENDA");
            $params["DTCREDITO"]    = $this->getParamValueFromConditions($filter, "DTCREDITO");
            
            $params["NRESTABELEC"] = is_array($params["NRESTABELEC"]) ? 
                $this->buildParamValue($params["NRESTABELEC"]) : "Todas";
            $params["NRADQUIRENTE"] = is_array($params["NRADQUIRENTE"]) ? 
                $this->buildParamValue($params["NRADQUIRENTE"]) : "Todas";
            
            $result = $this->ajustAdqService->chartDetails($params);
            $response->addDataSet(new DataSet("cnc01500_ajustes_adquirentes_details", $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }       
    }
    
    public function getParamValueFromConditions ($conditions, $paramName) {
        $obj = array_filter($conditions, function($param) use ($paramName) {
            return $param["columnName"] === $paramName;
        });
        
        return array_shift($obj)["value"];
    }
    
    public function buildParamValue ($arr) {
        return array_reduce($arr, function($accumulator, $element) {
            return $accumulator."|".$element;
        }, "")."|";
    }

}