<?php
namespace Teknisa\CNC\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Cnc01400CancelamentosAjustesFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    public function getCancelAdjustmentsFiltered($params, $query){
        $sql = $query; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function refreshCashFlow($params) {
        try {
            $procedure = new StoredProcedure($this->connection, 'ATUALIZA_FLUXO_DE_CAIXA');
            $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["P_CDEMPRESA"]));
            $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $params["P_CDFILIAL"]));
            $procedure->addParam(new Param('P_DTMOVFLUXO', Param::PARAM_INPUT, $params["P_DTCREDITO"]));
            $procedure->addParam(new Param('P_IDMOVFLUXO', Param::PARAM_INPUT, 'R'));
            $procedure->addParam(new Param('P_CDCLASSFINA', Param::PARAM_INPUT, $params["P_CDCLASSFINA"]));
            $procedure->addParam(new Param('P_VRENTMFLUXO', Param::PARAM_INPUT, $params["P_VRENTMFLUXO"]));
            $procedure->addParam(new Param('P_VRSAIMFLUXO', Param::PARAM_INPUT, $params["P_VRSAIMFLUXO"]));
            $procedure->execute();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function refreshBankBalance($params) {
        try{ 
            $procedure = new StoredProcedure($this->connection, 'ATUALIZA_SALDO_BANCARIO');
            $procedure->addParam(new Param('P_CDREDUCONT', Param::PARAM_INPUT, $params["P_CDREDUCONT"]));
            $procedure->addParam(new Param('P_DTSALDO', Param::PARAM_INPUT, $params["P_DTCREDITO"]));
            $procedure->addParam(new Param('P_VRSDOCCORR', Param::PARAM_INPUT, $params["P_VRSDOCCORR"]));
            $procedure->addParam(new Param('P_IDATUALIZA', Param::PARAM_INPUT, '1'));
            $procedure->execute();
        } catch (\Exception $e) {
                throw $e;
        }
    }
    
    public function ctbBcoLanc($params) {
        try {
                $procedure = new StoredProcedure($this->connection, 'CTB_BCO_LANC');
                $procedure->addParam(new Param('P_CDREDUCONT', Param::PARAM_INPUT, $params["P_CDREDUCONT"]));
                $procedure->addParam(new Param('P_NRMOVI', Param::PARAM_INPUT, $params["P_NRLANCCTBTEMP"]));
                $procedure->addParam(new Param('P_IDTIPO', Param::PARAM_INPUT, $params["P_IDTIPO"]));
                $procedure->addParam(new Param('P_NRLANCCTB', Param::PARAM_OUTPUT, '', Param::PARAM_TYPE_STR, 12));
                return $procedure->execute();
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getCancelAdjustments($params){
        $sql = "SELECT AJ.DTVENDA, AJ.DTCREDITO, AJ.NRRETFINANCADQ, AJ.NRLOTEVENDA, AJ.CDLOTEVENDA, AJ.NRESTABELEC, AJ.NRORG, AJ.CDESTABELEC, AJ.NMESTABELEC, AJ.NRADQUIRENTE, AJ.NMADQUIRENTE, AJ.IDGERAFINANC,
                    AJ.NRPRODUTOADQ, AJ.NMPRODUTOADQ, AJ.CDNSU, AJ.DSAJUSTE,  AJ.CDEMPRESA, AJ.VRLIQPGTO, AJ.IDCONCILIADO, AJ.IDSITUACAO,  AJ.IDSTATUSVENDA, AJ.NRMOVBANC, AJ.CDFILIAL, AJ.CDREDUCONT,
                    AJ.CDTPCTRECEB, AJ.CDTPDBDEBGER, AJ.CDTPCREDBANC, CR.IDCTBLCRBANC, DE.IDCTBLDBBANC, 
                    DECODE (AJ.IDSTATUSVENDA, 'C', DE.CDCLASSFINA, CR.CDCLASSFINA) CDCLASSFINA, DECODE(AJ.IDSTATUSVENDA, 'E', 'Credito', 'P', 'Debito', 'C', 'Cancelamento') TIPO
                    FROM 
                        (SELECT TO_CHAR(R.DTVENDA, 'DD/MM/YYYY') DTVENDA, TO_CHAR(R.DTCREDITO, 'DD/MM/YYYY') DTCREDITO, R.NRRETFINANCADQ, L.NRLOTEVENDA, L.CDLOTEVENDA, E.NRESTABELEC, E.CDESTABELEC, E.NRORG,
                            E.NMESTABELEC, A.NRADQUIRENTE, A.NMADQUIRENTE, A.IDGERAFINANC, P.NRPRODUTOADQ, P.NMPRODUTOADQ NMPRODUTOADQ, R.CDNSU, R.DSAJUSTE,  E.CDEMPRESA, 
                            R.VRLIQPGTO, DECODE(R.IDCONCILIADO, 'C', 'Sim', 'Não') IDCONCILIADO, R.IDSITUACAO,  R.IDSTATUSVENDA, R.NRMOVBANC, E.CDFILIAL, 
                            BUSCA_PARAMETRO_CNC(E.NRESTABELEC, A.NRADQUIRENTE, P.NRPRODUTOADQ, 'CONTCORR', 'N', NULL, NULL)CDREDUCONT,
                            BUSCA_PARAMETRO_CNC(E.NRESTABELEC, A.NRADQUIRENTE, P.NRPRODUTOADQ, 'TIPOCONTA', 'N', NULL, NULL) CDTPCTRECEB,
                            A.CDTPDBDEBGER,
                            BUSCA_PARAMETRO_CNC(E.NRESTABELEC, A.NRADQUIRENTE, P.NRPRODUTOADQ, 'TIPOCRED', 'N', NULL, NULL) CDTPCREDBANC
                               FROM ADQUIRENTE A, PRODUTOADQ P, ESTABELECIMENTO E, RETFINANCADQ R LEFT JOIN LOTEVENDA L
                                                                                                         ON R.NRLOTEVENDA = L.NRLOTEVENDA
                                WHERE R.NRADQUIRENTE = A.NRADQUIRENTE
                                  AND R.NRPRODUTOADQ = P.NRPRODUTOADQ
                                  AND R.NRESTABELEC = E.NRESTABELEC
                                  AND ((INSTR (:P_NRESTABELEC, '|'||TO_CHAR(E.NRESTABELEC)||'|') > 0) OR ('T' = :P_TNRESTABELEC))
                                  AND ((INSTR (:P_NRADQUIRENTE,     '|'||TO_CHAR(A.NRADQUIRENTE)||'|') > 0) OR ('T' = :P_TNRADQUIRENTE))
                                  AND ((INSTR (:P_NRPRODUTOADQ, '|'||TO_CHAR(P.NRPRODUTOADQ)||'|') > 0) OR ('T' = :P_TNRPRODUTOADQ))
                                  AND ((:P_IDCONCILIADO = TO_CHAR(R.IDCONCILIADO)) OR ('T' = :P_IDCONCILIADO))
                                  AND (((TRUNC(R.DTCREDITO) BETWEEN TO_DATE(:DTCREDITOINI, 'DD/MM/YY') AND TO_DATE(:DTCREDITOFIN, 'DD/MM/YY'))) OR ('T' = :P_TDTCREDITO))
                                  AND (((TRUNC(R.DTVENDA) BETWEEN TO_DATE(:DTVENDAINI, 'DD/MM/YY') AND TO_DATE(:DTVENDAFIN, 'DD/MM/YY')))OR ('T' = :P_TDTVENDA))
                                  AND R.IDSTATUSVENDA IN ('C','E','P')
                                  ORDER BY R.DTVENDA, R.DTCREDITO, E.NRESTABELEC, E.NMESTABELEC, A.NMADQUIRENTE, R.VRLIQPGTO)AJ
                                   LEFT JOIN TPCREDBANC CR
                                          ON AJ.CDTPCREDBANC = CR.CDTPCREDBANC 
                                   LEFT JOIN TPDEBIBANC DE
                                          ON AJ.CDTPDBDEBGER = DE.CDTPDEBIBANC "; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     public function validateBankFinestadq($params){
        $sql = "SELECT  BF.CDTPDBDEBGER, BF.CDTPCREDBANC, BF.CDREDUCONT,
                TC.IDCTBLCRBANC, TD.IDCTBLDBBANC, BF.CDTPDEBIBANC
                FROM (SELECT BUSCA_PARAMETRO_CNC(:NRESTABELEC, :NRADQUIRENTE, :NRPRODUTOADQ, 'CONTCORR', 'N', NULL, NULL)CDREDUCONT,
                            BUSCA_PARAMETRO_CNC(:NRESTABELEC, :NRADQUIRENTE, :NRPRODUTOADQ, 'TIPODEBGER', 'N', NULL, NULL)CDTPDBDEBGER,
                            BUSCA_PARAMETRO_CNC(:NRESTABELEC, :NRADQUIRENTE, :NRPRODUTOADQ, 'TIPOCRED', 'N', NULL, NULL) CDTPCREDBANC,
                            BUSCA_PARAMETRO_CNC(:NRESTABELEC, :NRADQUIRENTE, :NRPRODUTOADQ, 'TIPODEB', 'N', NULL, NULL) CDTPDEBIBANC,
                            BUSCA_PARAMETRO_CNC(:NRESTABELEC, :NRADQUIRENTE, :NRPRODUTOADQ, 'TIPOCREDGER', 'N', NULL, NULL) CDTPCREDBANCGER
                FROM DUAL)BF
                 LEFT JOIN TPCREDBANC TC
                  ON BF.CDTPCREDBANC = TC.CDTPCREDBANC
                 LEFT JOIN TPDEBIBANC TD
                  ON BF.CDTPDBDEBGER = TD.CDTPDEBIBANC"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    } 
    
    public function validateAdjustmentDate($params){
        $sql = "SELECT C.CDEMPRESA, R.NRESTABELEC, R.DTCREDITO, C.DTINICCTBL, C.DTFINACCTBL
                  FROM RETFINANCADQ R
                    JOIN ESTABELECIMENTO E
                      ON R.NRESTABELEC = E.NRESTABELEC
                          JOIN CONTOPECTBL C
                            ON C.CDEMPRESA = E.CDEMPRESA
                   WHERE R.NRRETFINANCADQ = :NRRETFINANCADQ
                       AND  R.DTCREDITO BETWEEN C.DTINICCTBL AND C.DTFINACCTBL"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function validateContNotaFiscal($params){
        $sql = "SELECT CDFILIAL, NRLANCTONF FROM RETVENDAADQ 
                WHERE CDNSU = :CDNSU
                  AND DTVENDA = :DTVENDA
                  AND NRADQUIRENTE = :NRADQUIRENTE "; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getClient($params){
        $sql = "SELECT  CDCLIENTE
                FROM ADQUIRENTE 
                WHERE NRADQUIRENTE = :NRADQUIRENTE"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getErrors($params){
        $sql = "SELECT COUNT(*) QT
                              FROM ERROCTBTEMP
                             WHERE CDEMPRESA = :CDEMPRESA
                               AND NRLANCCTBTEMP = :NRLANCCTBTEMP"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getError($params){
        $sql = "SELECT CDERROTEMP, NRSEQCTBTEMP
                              FROM ERROCTBTEMP
                             WHERE CDEMPRESA = :CDEMPRESA
                               AND NRLANCCTBTEMP = :NRLANCCTBTEMP"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function deleteErrors($params){
        $sql = "DELETE
                      FROM ERROCTBTEMP
                     WHERE CDEMPRESA = :CDEMPRESA
                       AND NRLANCCTBTEMP = :NRLANCCTBTEMP"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        $sql = "DELETE
                      FROM LANCCTBTEMP
                     WHERE CDEMPRESA = :CDEMPRESA
                       AND NRLANCCTBTEMP = :NRLANCCTBTEMP"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
         $sql = "DELETE
                      FROM RATECTBTEMP
                     WHERE CDEMPRESA = :CDEMPRESA
                       AND NRLANCCTBTEMP = :NRLANCCTBTEMP"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
    
    public function deleteContNotaFiscal($params){
        $sql = "DELETE
                      FROM AJCTRECEBER
                     WHERE CDFILIAL = :CDFILIAL
                       AND NRLANCTONF = :NRLANCTONF"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        $sql = "DELETE
                      FROM CONTARECEBER
                     WHERE CDFILIAL = :CDFILIAL
                       AND NRLANCTONF = :NRLANCTONF"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        $sql = "UPDATE RETVENDAADQ
                     SET CDFILIAL   = NULL,
                         NRLANCTONF = NULL
                 WHERE CDFILIAL   = :CDFILIAL
                   AND NRLANCTONF = :NRLANCTONF"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        $sql = "DELETE
                      FROM NOTAFISCAL
                     WHERE CDFILIAL = :CDFILIAL
                       AND NRLANCTONF = :NRLANCTONF"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        
    }
    
    public function changeBankMove($params){
        $sql = "INSERT INTO MOVBANCARIO
                           (CDREDUCONT, NRMOVBANC, DTMOVBANC, IDMOVBANC, DSHISMBANC, VRMOVBANC, IDORIGMBANC, IDSTCONEXT,
                            IDSTATUSCTBBANC, NRORG, NRDOCMBANC)
                         VALUES
                           (:CDREDUCONT, :NRMOVBANC, :DTCREDITO, :IDDEBCRED, :DESCMOVBANC, ABS(:VRLIQPGTO), 'P', '0',
                            'P', :EST_NRORG, SUBSTR(:CDNSU, 1, 10))";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /* DESVINCULA A MOVIMENTAÇÃO DO BCO COM A VENDA. PARA GERAR UM NOVO SEQUENCIAL DE ACORDO COM A NOVA CONTA. */
    public function clearBankMoveRet($params){
        $sql = "UPDATE RETFINANCADQ
                SET CDREDUCONT = NULL,
                    NRMOVBANC = NULL
              WHERE NRRETFINANCADQ = :NRRETFINANCADQ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /* DELETA A MOVIMENTAÇÃO BANCÁRIA */                      
        public function clearBankMove($params){
        $sql = "DELETE
                   FROM MOVBANCARIO
                  WHERE CDREDUCONT = :CDREDUCONT
                    AND NRMOVBANC = :NRMOVBANC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function changeMoveDebBanc($params){
        $sql = "INSERT INTO MOVDEBBANC
                        (CDREDUCONT, NRMOVIDEBI, CDCLASSFINA, CDEMPRESA, CDFILIAL, NRMOVBANC, CDTPDEBIBANC,
                         DTMOVIDEBI, DSMOVIDEBI, VRMOVIDEBI, IDLANCOMCONTPAG, NRORG, CDCLIENTE,
                         CDFILILANDEB, CDECTBMDEB)
                      VALUES
                        (:CDREDUCONT, :NRMOVIDEBI, :CDCLASSFINA, :CDEMPRESA, :CDFILIAL, :NRMOVBANC, :CDTPDEBIBANC,
                         :DTCREDITO, :DESCMOV, ABS(:VRLIQPGTO), 'N', :EST_NRORG, :CDCLIENTE,
                         :CDFILIAL, :CDECTBMDEB)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function lancDeb($params){
        $sql = "DELETE
              FROM LANCCONT L
             WHERE EXISTS (SELECT 1
                             FROM MOVDEBBANC M
                            WHERE L.CDEMPRESA = M.CDEMPRESA
                              AND L.NRLANCCONT = M.NRLCTBMDEB
                              AND M.CDREDUCONT = :CDREDUCONT
                              AND M.NRMOVBANC = :NRMOVBANC)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function movDebBanc($params){
        $sql = "DELETE
                  FROM MOVDEBBANC
                 WHERE CDREDUCONT = :CDREDUCONT
                   AND NRMOVBANC = :NRMOVBANC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function changeMoveCredBanc($params){
        $sql = "INSERT INTO MOVCREDBANC
                        (CDREDUCONT, NRMOVICRED, CDCLASSFINA, CDEMPRESA, CDFILIAL, NRMOVBANC, CDTPCREDBANC,
                         DTMOVICRED, DSMOVICRED, VRMOVICRED, IDLANCOMCONTREC, NRORG, CDCLIENTE,
                         CDFILILANCRE, CDECTBMCRED)
                      VALUES
                        (:CDREDUCONT, :NRMOVICRED, :CDCLASSFINA, :CDEMPRESA, :CDFILIAL, :NRMOVBANC, :CDTPCREDBANC,
                         :DTCREDITO, :DESCMOV, ABS(:VRLIQPGTO), 'N', :EST_NRORG, :CDCLIENTE,
                         :CDFILIAL, :CDECTBMCRED)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
      public function lancCred($params){
        $sql = "DELETE
              FROM LANCCONT L
             WHERE EXISTS (SELECT 1
                             FROM MOVCREDBANC M
                            WHERE L.CDEMPRESA = M.CDEMPRESA
                              AND L.NRLANCCONT = M.NRLCTBMCRED
                              AND M.CDREDUCONT = :CDREDUCONT
                              AND M.NRMOVBANC = :NRMOVBANC)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function movCredBanc($params){
        $sql = "DELETE
                  FROM MOVCREDBANC
                 WHERE CDREDUCONT = :CDREDUCONT
                   AND NRMOVBANC = :NRMOVBANC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function changeSituationAdjustments($params){
        $sql = "UPDATE RETFINANCADQ
                    SET IDCONCILIADO = :IDCONCILIADO,
                        IDSITUACAO   = :IDSITUACAO
                WHERE NRRETFINANCADQ = :NRRETFINANCADQ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function changeMovBancAdjustments($params){
        $sql = "UPDATE RETFINANCADQ
                    SET CDREDUCONT   = :CDREDUCONT,
                        NRMOVBANC    = :NRMOVBANC
                WHERE NRRETFINANCADQ = :NRRETFINANCADQ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getCdTpBancs($params){
        $sql = "SELECT CDTPDBDEBGER, CDTPCREDBANCGER 
                    FROM ADQUIRENTE
                    WHERE NRADQUIRENTE = :NRADQUIRENTE"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getIdDebBanc($params){
        $sql = "SELECT IDCTBLDBBANC 
                    FROM TPDEBIBANC
                    WHERE CDTPDEBIBANC = :CDTPDEBIBANC"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getIdCredBanc($params){
        $sql = "SELECT IDCTBLCRBANC
                    FROM TPCREDBANC
                    WHERE CDTPCREDBANC = :CDTPCREDBANC"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function checkCDCLASSFINADebito($params){
        $sql = "
        SELECT DE.CDCLASSFINA CDCLASSFINA, IDCTBLDBBANC FROM 
        (SELECT R.IDSTATUSVENDA, A.CDTPDBDEBGER
        FROM ADQUIRENTE A, PRODUTOADQ P, ESTABELECIMENTO E, RETFINANCADQ R 
            WHERE R.NRADQUIRENTE = A.NRADQUIRENTE
              AND R.NRPRODUTOADQ = P.NRPRODUTOADQ
              AND R.NRESTABELEC = E.NRESTABELEC
              AND R.IDSTATUSVENDA IN ('C','E','P') 
              AND R.NRRETFINANCADQ = :NRRETFINANCADQ) AJ
               LEFT JOIN TPDEBIBANC DE
                      ON AJ.CDTPDBDEBGER = DE.CDTPDEBIBANC
        ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function checkCDCLASSFINACredito($params){
        $sql = "
        SELECT CR.CDCLASSFINA CDCLASSFINA, IDCTBLCRBANC FROM 
        (SELECT R.IDSTATUSVENDA, A.CDTPCREDBANCGER
        FROM ADQUIRENTE A, PRODUTOADQ P, ESTABELECIMENTO E, RETFINANCADQ R 
            WHERE R.NRADQUIRENTE = A.NRADQUIRENTE
              AND R.NRPRODUTOADQ = P.NRPRODUTOADQ
              AND R.NRESTABELEC = E.NRESTABELEC
              AND R.NRRETFINANCADQ = :NRRETFINANCADQ)AJ
               LEFT JOIN TPCREDBANC CR
                      ON AJ.CDTPCREDBANCGER = CR.CDTPCREDBANC 
        ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }

    
    public function checkCDCLASSFINACancelamento($params){
        $CDTPDEBIBANC = self::checkCDTPDEBIBANC($params);
        $sql = "
            SELECT CDCLASSFINA FROM TPDEBIBANC WHERE CDTPDEBIBANC = :CDTPDEBIBANC
        ";
        $std = $this->connection->prepare($sql);
        $std->execute($CDTPDEBIBANC);
        return $std->fetch();
    }
    
    public function checkCDTPDEBIBANC($params){
        $sql = "
            SELECT BUSCA_PARAMETRO_CNC(
                                      :P_NRESTABELEC,
                                      :P_NRADQUIRENTE,
                                      :P_NRPRODUTOADQ,
                                      :P_TIPOPARAM,
                                      :P_GRAVAERRO,
                                      :P_DTINICIAL,
                                      :P_DTFINAL) AS CDTPDEBIBANC FROM DUAL
        ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function checkFinancAdq($param){
         $sql = "
         SELECT IDGERAFINANC, CDTPDBDEBGER, CDTPCREDBANCGER FROM ADQUIRENTE WHERE NRADQUIRENTE = :NRADQUIRENTE
         ";
         $std = $this->connection->prepare($sql);
         $std->execute($param);
         return $std->fetch();  
    }
    
   public function checkInfoRetfinanc($param){
         $sql = "
         SELECT DECODE(IDCONCILIADO, 'C', 'Sim', 'Não') IDCONCILIADO, IDSITUACAO, IDSTATUSVENDA FROM RETFINANCADQ WHERE NRRETFINANCADQ = :NRRETFINANCADQ
         ";
         $std = $this->connection->prepare($sql);
         $std->execute($param);
         return $std->fetch();  
    }

     public function searchParamsCnc($param){
          $sql = "
          SELECT 
          BUSCA_PARAMETRO_CNC(:NRESTABELEC, :NRADQUIRENTE, :NRPRODUTOADQ, 'CONTCORR', 'N', NULL, NULL)CDREDUCONT,
          BUSCA_PARAMETRO_CNC(:NRESTABELEC, :NRADQUIRENTE, :NRPRODUTOADQ, 'TIPOCRED', 'N', NULL, NULL)CDTPCREDBANC
          FROM DUAL
          ";
         $std = $this->connection->prepare($sql);
         $std->execute($param);
         return $std->fetch();  
     }
     


    
}