<?php

namespace Teknisa\CNC\Factories;

use Doctrine\ORM\EntityManager;

class Cnc01600CadastroEstabelecimentoFactory {
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }

    public function getEstabelecParam ($params) {
        $sql = "SELECT EST.NRESTABELEC, EST.CDESTABELEC, EST.NMESTABELEC, 
                 EST.CDINSCESTA, EST.CDINSCMUNI, EST.CDFILIAL,
                 EST.NMFILIAL, EST.CDEMPRESA
                  FROM(SELECT E.NRESTABELEC, E.CDESTABELEC, E.NMESTABELEC,  
                              E.CDINSCESTA, E.CDINSCMUNI, 
                               E.CDFILIAL, F.NMFILIAL, E.CDEMPRESA
                                FROM ESTABELECIMENTO E 
                                                    LEFT JOIN FILIAL F 
                                                           ON F.NRORG = E.NRORG
                                                           AND E.CDFILIAL = F.CDFILIAL 
                                WHERE E.NRORG = :NRORG
                                  AND ((UPPER(E.CDESTABELEC || E.NMESTABELEC) LIKE '%' || UPPER(:ALL_FIELDS) || '%') OR (:TALL_FIELDS = 'T')) ) EST
                                ORDER BY EST.NRESTABELEC, EST.NMESTABELEC, EST.CDESTABELEC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getEmpresaFilial ($params) {
        $sql = "SELECT CDEMPRESA, CDINSCESTA, CDINSCMUNI, NRINSJURFILI
                  FROM FILIAL
                   WHERE CDFILIAL = :CDFILIAL
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0];
    }
    
    public function getAgencias ($params) {
        $sql = "SELECT DISTINCT A.NMAGENCIA, C.CDAGENCIA
                  FROM CONTCORR C JOIN AGENCIA A
                   ON C.CDAGENCIA = A.CDAGENCIA
                    WHERE C.CDEMPRESA = :CDEMPRESA
                    AND C.NRORG = A.NRORG
                     AND A.CDBANCO = :CDBANCO
                     AND C.NRORG = :NRORG
                  ORDER BY A.NMAGENCIA";        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getContas ($params) {
        $sql = "SELECT DISTINCT CDCONTCORR, DSCONTCORR
                    FROM CONTCORR
                    WHERE CDEMPRESA = :CDEMPRESA
                      AND CDBANCO = :CDBANCO
                      AND CDAGENCIA = :CDAGENCIA 
                      AND NRORG = :NRORG 
                      ORDER BY CDCONTCORR";        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function saveEstabelec($params) {
        $sql = "UPDATE ESTABELECIMENTO
                  SET NMESTABELEC       = :NMESTABELEC,
                      CDFILIAL          = :CDFILIAL,
                      CDEMPRESA         = :CDEMPRESA,
                      CDINSCESTA        = :CDINSCESTA,
                      CDINSCMUNI        = :CDINSCMUNI,
                      CDSERIE           = :CDSERIE
                WHERE NRORG = :NRORG
                  AND NRESTABELEC = :NRESTABELEC";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function saveEstabelecName($params) {
        $sql = "UPDATE ESTABELECIMENTO
                  SET NMESTABELEC       = :NMESTABELEC,
                      CDFILIAL          = :CDFILIAL,
                      CDEMPRESA         = :CDEMPRESA,
                      CDINSCESTA        = :CDINSCESTA,
                      CDINSCMUNI        = :CDINSCMUNI
                WHERE NRORG = :NRORG
                  AND NRESTABELEC = :NRESTABELEC";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function deleteEstabelecContcor ($params) {
        $sql = "DELETE FROM CONTCORESTAB
                WHERE NRORG = :NRORG
                  AND NRESTABELEC = :NRESTABELEC";
        
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }

    public function getCdEmpresa ($params) {
        $sql = "SELECT CDEMPRESA, NRINSJURFILI
                FROM FILIAL
                WHERE NRORG = :NRORG
                  AND CDFILIAL = :CDFILIAL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0];
    }    
    
    public function getFilialParams ($params) {
        $sql = "SELECT F.CDFILIAL, F.CDEMPRESA, F.CDINSCESTA, F.CDINSCMUNI, E.CDSERIE
                  FROM FILIAL F
                        LEFT JOIN ESTABELECIMENTO E
                            ON E.NRORG = F.NRORG
                            AND E.NRESTABELEC = :NRESTABELEC
                   WHERE F.NRORG = :NRORG
                   AND F.CDFILIAL = :CDFILIAL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

}