<?php

namespace WebServiceCall\Connection;

use WebServiceCall\Repository\FileManager\DBManager;

// Link para a documentação das funções de OCI8 - http://php.net/manual/en/ref.oci8.php
class OCI8Connection {
    private static $conn = null;

    private function __clone() {}
    
    private function __wakeup() {}

    private function isSAAS($dbData) {
        return $dbData->getUsername() === 'USR_ORG_SAAS';
    }
    
    private function doesDBUseWallet($dbData) {
        return $dbData->getWalletBool();
    }
    
    private function getSAASDBName($dbData, $nrorg) {
        if(empty($nrorg)) {
            throw new \Exception(self::EMPTY_POST_PARAMS);
        }
        return $dbData->getWalletPrefix() . $nrorg;
    }
    
    // https://www.php.net/manual/pt_BR/features.persistent-connections.php
    private function getSAASConnection($dbData, $nrorg) {
        // oci_connect should be more efficient in SAAS.
        $conn = oci_connect(
            $dbData->getUsername(), 
            $dbData->getPassword(), 
            $this->getSAASDBName($dbData, $nrorg),
            $dbData->getCharset(),
            OCI_CRED_EXT // Use Wallet const.
        );
    }
    
    // https://www.php.net/manual/pt_BR/features.persistent-connections.php
    private function getWalletConnection($dbData) {
        // oci_pconnect should be more efficient in HOSTING or other clients which uses Oracle Wallet.
        return oci_pconnect(
            "/",
            NULL,
            $dbData->getDBName(), 
            $dbData->getCharset(), 
            OCI_CRED_EXT
        );
    }

    private function getRegularConnection($dbData) {
        return oci_pconnect(
            $dbData->getUsername(), 
            $dbData->getPassword(),
            $dbData->getHost() . '/' . $dbData->getDBName(),
            $dbData->getCharset()
        );
    }
    
    private function factoryConnection($nrorg) {
        try {
            $dbFileManager = new DBManager();
            $dbData = $dbFileManager->getData();
            
            if( $this->doesDBUseWallet($dbData) ) {
                if($this->isSAAS($dbData)) {
                    return $this->getSAASConnection($dbData, $nrorg);
                } else {
                    return $this->getWalletConnection($dbData);
                }
            } else { 
                return $this->getRegularConnection($dbData);
            }
        } catch(\Exception $e) {
            $errorMsg = "Não foi possível se conectar ao Oracle DB: ". $e->getMessage();
            throw new \Exception($errorMsg);
        }
    }
    
    private function getNRORG() {
        return $_POST['NRORG'];
    }
    
    private function __construct() {
        $nrorg = $this->getNRORG();
        self::$conn = $this->factoryConnection($nrorg);
        oci_set_client_info(self::$conn, 'CNC_WS.php');
    }
    
    public static function getConnection() {
        if(!self::$conn) {
            new self;
        }
        
        return self::$conn;
    }
}